#!/bin/bash

PI_MOD_NAME=$1
if [ -z "${PI_MOD_NAME}" ] || [ "${PI_MOD_NAME}" != "${PI_MOD_NAME//[^a-zA-Z0-9]/}" ] ; then
   echo "Improper module name ${PI_MOD_NAME}" > ${HOME}/.pushinfo.error
   exit 1
fi

PI_SITE_DIR='/etc/pushinfo/sites'
PI_MOD_CONF="/etc/pushinfo/client/conf/${PI_MOD_NAME}.conf"
PI_MOD_INFO_DIR="/etc/pushinfo/${PI_MOD_NAME}.d"

# read the module config file
if [ -r "${PI_MOD_CONF}" ] ; then
   . ${PI_MOD_CONF}
else
   echo "No ${PI_MOD_NAME} module config file ${PI_MOD_CONF}" >> \
         ${HOME}/.pushinfo.error
   exit 1
fi

if [ -z "${PI_SITE}" ] || [ "${PI_SITE}" != "${PI_SITE//[^-_a-zA-Z0-9.]/}" ] ; then
   PI_SITE=info
fi

# read the site config file
if [ -r "${PI_SITE_DIR}/${PI_SITE}/site" ] ; then
   . ${PI_SITE_DIR}/${PI_SITE}/site
else
   echo "No site config file ${PI_SITE_DIR}/${PI_SITE}/site" >> \
         ${HOME}/.pushinfo.error
   exit 1
fi

# check if module is enabled
if [ -z "$( cat <<< ${PI_CLIENT_MODS} | grep -w "${PI_MOD_NAME}" )" ] ; then 
   exit 0
fi

# basic parameter set
if [ -z "${PI_KEY}" ] ; then
   echo "Undefined pushinfo key" >> ${HOME}/.pushinfo.error
   exit 1
fi
PI_PARAM=":key:=${PI_KEY}"
PI_PARAM_DEF="${PI_PARAM}"

# external scripts
# detect settings, add to PI_PARAM, and push
if [ -d "${PI_MOD_INFO_DIR}" ] ; then
  for i in ${PI_MOD_INFO_DIR}/*.sh ; do
    if [ -r "${i}" ] ; then
      . ${i}
    fi
  done
  unset i
fi

